@@ -255,6 +255,18 @@ class CallBytes(ScaleType):
         return bytes.fromhex(value[2:])
 
 
+class RawBytes(ScaleType):
+
+    type_string = '&[u8]'
+
+    def process(self):
+        self.value_object = self.get_remaining_bytes()
+        return f'0x{self.value_object.hex()}'
+
+    def process_encode(self, value):
+        return ScaleBytes(bytes.fromhex(value[2:]))
+
+
 class U8(ScaleType):
 
     def process(self):
@@ -781,12 +793,12 @@ class Vec(ScaleType):
 
         # Check for Bytes processing
         if self.runtime_config.get_decoder_class(self.sub_type) is U8:
-            value = self.get_next_bytes(element_count)
+            self.value_object = self.get_next_bytes(element_count)
 
             try:
-                return value.decode()
+                return self.value_object.decode()
             except UnicodeDecodeError:
-                return '0x{}'.format(value.hex())
+                return '0x{}'.format(self.value_object.hex())
 
         result = []
         for _ in range(0, element_count):
@@ -1482,6 +1494,7 @@ class GenericContractExecResult(Enum):
     def __init__(self, data=None, contract_result_scale_type=None, **kwargs):
         self.contract_result_scale_type = contract_result_scale_type
         self.gas_consumed = None
+        self.gas_required = None
         self.flags = None
         self.contract_result_data = None
         super().__init__(data, **kwargs)
@@ -1494,6 +1507,7 @@ class GenericContractExecResult(Enum):
     def process_contract_result(self):
         if 'success' in self.value:
             self.gas_consumed = self.value['success']['gas_consumed']
+            self.gas_required = self.value['success']['gas_required']
             self.flags = self.value['success']['flags']
             self.contract_result_data = self.value['success']['data']
 
@@ -1981,6 +1995,35 @@ class GenericRegistryType(Struct):
 
         return super().process_encode(value)
 
+    def retrieve_type_decomposition(self):
+        if 'variant' in self.value['def']:
+            for variant in self.value['def']['variant']['variants']:
+                for field in variant['fields']:
+                    field_obj = self.runtime_config.create_scale_object(f"scale_info::{field['type']}")
+                    variant['value'] = field_obj.scale_info_type.retrieve_type_decomposition()
+
+        elif 'composite' in self.value['def']:
+            for field in self.value['def']['composite']['fields']:
+                field_obj = self.runtime_config.create_scale_object(f"scale_info::{field['type']}")
+                field['value'] = field_obj.scale_info_type.retrieve_type_decomposition()
+
+        elif 'array' in self.value['def']:
+            type_def = self.value['def']['array']
+            array_element_obj = self.runtime_config.create_scale_object(f"scale_info::{type_def['type']}")
+            type_def['value'] = array_element_obj.scale_info_type.retrieve_type_decomposition()
+
+        elif 'sequence' in self.value['def']:
+            type_def = self.value['def']['sequence']
+            array_element_obj = self.runtime_config.create_scale_object(f"scale_info::{type_def['type']}")
+            type_def['value'] = array_element_obj.scale_info_type.retrieve_type_decomposition()
+
+        elif 'tuple' in self.value['def']:
+            for idx, type_def in self.value['def']['tuple']:
+                element_obj = self.runtime_config.create_scale_object(f"scale_info::{type_def}")
+                self.value['def']['tuple'][idx] = element_obj.scale_info_type.retrieve_type_decomposition()
+
+        return self.value['def']
+
 
 class GenericField(Struct):
 
@@ -2283,6 +2326,9 @@ class GenericStorageEntryMetadata(Struct):
         else:
             raise NotImplementedError()
 
+    def get_param_info(self) -> list:
+        raise NotImplementedError()
+
 
 class ScaleInfoStorageEntryMetadata(GenericStorageEntryMetadata):
 
@@ -2332,6 +2378,14 @@ class ScaleInfoStorageEntryMetadata(GenericStorageEntryMetadata):
         else:
             raise NotImplementedError()
 
+    def get_param_info(self) -> list:
+        param_info = []
+        for param_type_string in self.get_params_type_string():
+            scale_type = self.runtime_config.create_scale_object(param_type_string)
+            param_info.append(scale_type.scale_info_type.retrieve_type_decomposition())
+
+        return param_info
+
 
 class GenericEventMetadata(Struct):
 
@@ -2413,8 +2467,7 @@ class GenericExtrinsic(ScaleType):
 
     @property
     def extrinsic_hash(self):
-        if self.signed:
-            return blake2b(self.data.data, digest_size=32).digest()
+        return blake2b(self.data.data, digest_size=32).digest()
 
     def process(self):
         self.value_object = {
